==> ejc-jltest-impl-3.0.0-20240311.091845-55-sources.jar: com/ejianc/business/jltest/orgtest/bean/DangeraDetailEntity.java <==
package com.ejianc.business.jltest.orgtest.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 重大事故隐患判定明细A
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_dangera_detail")
public class DangeraDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="dangera_id")
    private Long dangeraId; // 主表主键ID
    @TableField(value="detail_code")
    private String detailCode; // 隐患编号
    @TableField(value="detail_category")
    private Integer detailCategory; // 类别
    @TableField(value="detail_manage")
    private String detailManage; // 管理环节
    @TableField(value="hidden_trouble")
    private String hiddenTrouble; // 隐患内容
    @TableField(value="self_examination")
    private String selfExamination; // 自查情况
    @TableField(value="judgment_results")
    private String judgmentResults; // 判定结果
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    
    
    

    public Long getDangeraId() {
        return dangeraId;
    }

    public void setDangeraId(Long dangeraId) {
        this.dangeraId = dangeraId;
    }
    public String getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }
    public Integer getDetailCategory() {
        return detailCategory;
    }

    public void setDetailCategory(Integer detailCategory) {
        this.detailCategory = detailCategory;
    }
    public String getDetailManage() {
        return detailManage;
    }

    public void setDetailManage(String detailManage) {
        this.detailManage = detailManage;
    }
    public String getHiddenTrouble() {
        return hiddenTrouble;
    }

    public void setHiddenTrouble(String hiddenTrouble) {
        this.hiddenTrouble = hiddenTrouble;
    }
    public String getSelfExamination() {
        return selfExamination;
    }

    public void setSelfExamination(String selfExamination) {
        this.selfExamination = selfExamination;
    }
    public String getJudgmentResults() {
        return judgmentResults;
    }

    public void setJudgmentResults(String judgmentResults) {
        this.judgmentResults = judgmentResults;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    
}

==> ejc-jltest-impl-3.0.0-20240328.015927-125-sources.jar: com/ejianc/business/jltest/orgtest/bean/DangeraDetailEntity.java <==
package com.ejianc.business.jltest.orgtest.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 重大事故隐患判定明细A
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_dangera_detail")
public class DangeraDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="dangera_id")
    private Long dangeraId; // 主表主键ID
    @TableField(value="detail_code")
    private String detailCode; // 隐患编号
    @TableField(value="detail_category")
    private Long detailCategory; // 类别
    @TableField(value="detail_manage")
    private String detailManage; // 管理环节
    @TableField(value="hidden_trouble")
    private String hiddenTrouble; // 隐患内容
    @TableField(value="self_examination")
    private String selfExamination; // 自查情况
    @TableField(value="judgment_results")
    private String judgmentResults; // 判定结果
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    
    
    

    public Long getDangeraId() {
        return dangeraId;
    }

    public void setDangeraId(Long dangeraId) {
        this.dangeraId = dangeraId;
    }
    public String getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }

    public Long getDetailCategory() {
        return detailCategory;
    }

    public void setDetailCategory(Long detailCategory) {
        this.detailCategory = detailCategory;
    }

    public String getDetailManage() {
        return detailManage;
    }

    public void setDetailManage(String detailManage) {
        this.detailManage = detailManage;
    }
    public String getHiddenTrouble() {
        return hiddenTrouble;
    }

    public void setHiddenTrouble(String hiddenTrouble) {
        this.hiddenTrouble = hiddenTrouble;
    }
    public String getSelfExamination() {
        return selfExamination;
    }

    public void setSelfExamination(String selfExamination) {
        this.selfExamination = selfExamination;
    }
    public String getJudgmentResults() {
        return judgmentResults;
    }

    public void setJudgmentResults(String judgmentResults) {
        this.judgmentResults = judgmentResults;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    
}
